@@ -1,12 +1,33 @@
-import os, os.path
+# -*- coding: utf-8 -*-
+#
+# defaults.py.in sets many important default global variables
+# used throughout the game. Note that this file is processed by
+# automake to set prefix paths etc. Please keep defaults.py.in
+# in sync between glchess and gnome-sudoku. 
+
+import sys, os, os.path
 import errno
 import gettext
 
-APP_DATA_DIR = os.path.join('/home/thomas/oste/test', 'share') 
-IMAGE_DIR = os.path.join(APP_DATA_DIR, 'pixmaps', 'gnome-sudoku')
-LOCALEDIR = os.path.join(APP_DATA_DIR, 'locale')
-GLADE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
-BASE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
+if (sys.modules.has_key('gnome_sudoku') and
+    hasattr(sys.modules["gnome_sudoku"],'installed_mode') and
+    sys.modules["gnome_sudoku"].installed_mode):
+    # If the installed_mode attribute is not set, then we are
+    # importing from something other than the gnome-sudoku script; we
+    # assume anyone importing in this way is doing testing etc.
+    APP_DATA_DIR = os.path.join('/usr/local', 'share') 
+    IMAGE_DIR = os.path.join(APP_DATA_DIR, 'pixmaps', 'gnome-sudoku')
+    LOCALEDIR = os.path.join(APP_DATA_DIR, 'locale')
+    GLADE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
+    BASE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
+    PUZZLE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku','puzzles')    
+else:
+    APP_DATA_DIR = os.path.join('/home/jclinton/gnome-games', 'gnome-sudoku', 'data') 
+    IMAGE_DIR = os.path.join('/home/jclinton/gnome-games', 'gnome-sudoku', 'images')
+    LOCALEDIR = os.path.join(APP_DATA_DIR, 'locale')
+    GLADE_DIR = os.path.join('/home/jclinton/gnome-games', 'gnome-sudoku', 'glade')
+    BASE_DIR = os.path.join('/home/jclinton/gnome-games', 'gnome-sudoku', 'data')
+    PUZZLE_DIR = BASE_DIR
 
 DOMAIN = 'gnome-games'
 gettext.bindtextdomain(DOMAIN, LOCALEDIR)
@@ -16,10 +37,10 @@ import gtk.glade
 gtk.glade.bindtextdomain (DOMAIN, LOCALEDIR)
 gtk.glade.textdomain (DOMAIN)
 
-VERSION = "2.21.2"
+VERSION = "2.22.0"
 APPNAME = _("GNOME Sudoku")
 APPNAME_SHORT = _("Sudoku")
-COPYRIGHT = 'Copyright \xc2\xa9 2005-2007, Thomas M. Hinkle'
+COPYRIGHT = 'Copyright \xc2\xa9 2005-2008, Thomas M. Hinkle'
 DESCRIPTION = _('GNOME Sudoku is a simple sudoku generator and player. Sudoku is a japanese logic puzzle.\n\nGNOME Sudoku is a part of GNOME Games.')
 AUTHORS = ["Thomas M. Hinkle"]
 WEBSITE       = 'http://www.gnome.org/projects/gnome-games/'
